@@ -1,14 +1,15 @@
+from typing import List
 from typing import Optional
 
 from pydantic.class_validators import root_validator
 from pydantic.fields import Field
 
+from .content import TikTokContentModel
 from .base import BaseModelORM
 
 
 class TikTokUserModel(BaseModelORM):
     id: str = Field(..., alias="uid")
-    avatar_link: str = Field(..., alias="avatar_larger")
     name: str = Field(..., alias="nickname")
     username: str = Field(..., alias="unique_id")
     description: Optional[str] = Field(None, alias="signature")
@@ -18,8 +19,10 @@ class TikTokUserModel(BaseModelORM):
     likes_count: Optional[int] = Field(None, alias="total_favorited")
     verified: Optional[int] = Field(0, alias="verification_type")
 
-    @root_validator(pre=True)
-    def convert_data(cls, values):
-        values["avatar_larger"] = values.get("avatar_larger", {}).get("url_list", [""])[-1]
-
-        return values
+    avatar_168x168: TikTokContentModel
+    avatar_300x300: TikTokContentModel
+    avatar_larger: TikTokContentModel
+    avatar_medium: TikTokContentModel
+    avatar_thumb: TikTokContentModel
+    cover_url: Optional[List[TikTokContentModel]]
+    avatar_medium: TikTokContentModel
